aboutsummaryrefslogtreecommitdiff
path: root/background/storage.js
diff options
context:
space:
mode:
Diffstat (limited to 'background/storage.js')
-rw-r--r--background/storage.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/background/storage.js b/background/storage.js
index ea390ef..5578109 100644
--- a/background/storage.js
+++ b/background/storage.js
@@ -104,7 +104,7 @@
}
var pages;
- var bundles;
+ var bags;
var scripts;
var list_by_prefix = {};
@@ -310,8 +310,8 @@
*/
/*
* For bundles, item name is chosen by user, data is an array of 2-element
* arrays with type prefix and script/bundle names.
*/
/*
@@ -310,8 +310,8 @@
*/
/*
- * For bundles, item name is chosen by user, data is an array of 2-element
- * arrays with type prefix and script/bundle names.
+ * For bags, item name is chosen by user, data is an array of 2-element
+ * arrays with type prefix and script/bag names.
*/
/*